@@ -14,7 +14,7 @@
 import time
 import os
 import signal
-# from subprocess import PIPE
+from subprocess import PIPE
 
 from pilot.common.errorcodes import ErrorCodes
 from pilot.control.job import send_state
@@ -144,6 +144,37 @@ class Executor(object):
     def utility_after_payload_started(self, job):
         """
         Functions to run after payload started
+        :param job: job object
+        """
+
+        # get the payload command from the user specific code
+        pilot_user = os.environ.get('PILOT_USER', 'generic').lower()
+        user = __import__('pilot.user.%s.common' % pilot_user, globals(), locals(), [pilot_user], 0)  # Python 2/3
+
+        # should any additional commands be executed after the payload?
+        cmd_dictionary = user.get_utility_commands(order=UTILITY_AFTER_PAYLOAD_STARTED, job=job)
+        if cmd_dictionary:
+            cmd = '%s %s' % (cmd_dictionary.get('command'), cmd_dictionary.get('args'))
+            logger.info('utility command to be executed after the payload: %s' % cmd)
+
+            # how should this command be executed?
+            utilitycommand = user.get_utility_command_setup(cmd_dictionary.get('command'), job)
+            if not utilitycommand:
+                logger.warning('empty utility command - nothing to run')
+                return
+            try:
+                proc1 = execute(utilitycommand, workdir=job.workdir, returnproc=True, usecontainer=False,
+                                stdout=PIPE, stderr=PIPE, cwd=job.workdir, job=job)
+            except Exception as e:
+                logger.error('could not execute: %s' % e)
+            else:
+                # store process handle in job object, and keep track on how many times the command has been launched
+                # also store the full command in case it needs to be restarted later (by the job_monitor() thread)
+                job.utilities[cmd_dictionary.get('command')] = [proc1, 1, utilitycommand]
+
+    def utility_after_payload_started_new(self, job):
+        """
+        Functions to run after payload started
 
         REFACTOR
 
@@ -353,7 +384,7 @@ class Executor(object):
         #if _cmd:
         #    logger.info('could have executed: %s' % _cmd)
 
-        # self.utility_after_payload_started(job)
+        self.utility_after_payload_started(job)
 
         return proc
 
